@@ -1,4 +1,4 @@
-# CytoPipeline - Copyright (C) <2022-2025>
+# CytoPipeline - Copyright (C) <2022-2026>
 # <Université catholique de Louvain (UCLouvain), Belgique>
 #
 #   Description and complete License: see LICENSE file.
@@ -35,6 +35,7 @@
 #' @param specificScatterChannels vector of scatter channels for which we 
 #' still want to apply the fluo method (and not the scatter Method)
 #' @param verbose if TRUE, send messages to the user at each step
+#' @param ... additional parameters passed to flowCore::estimateLogicle()
 #'
 #' @return a flowCore::flowFrame with removed low quality events from the input
 #' @export
@@ -60,7 +61,8 @@ estimateScaleTransforms <- function(ff,
                                                       "linearQuantile"),
                                     scatterRefMarker = NULL,
                                     specificScatterChannels = NULL,
-                                    verbose = FALSE){
+                                    verbose = FALSE,
+                                    ...){
     fluoMethod <- match.arg(fluoMethod)
     scatterMethod <- match.arg(scatterMethod)
     
@@ -72,7 +74,7 @@ estimateScaleTransforms <- function(ff,
             ) 
         }
         fluoCols <- flowCore::colnames(ff)[areFluoCols(ff)]
-        transList <- flowCore::estimateLogicle(ff, fluoCols)
+        transList <- flowCore::estimateLogicle(ff, fluoCols, ...)
     } # else do nothing
     
     if (scatterMethod == "linearQuantile") {
@@ -121,7 +123,8 @@ estimateScaleTransforms <- function(ff,
         
         transList <- c(transList, 
                        flowCore::estimateLogicle(ff, 
-                                                 effectiveScatterChannels))
+                                                 effectiveScatterChannels,
+                                                 ...))
     }
     
     return(transList)
@@ -226,6 +229,11 @@ readSampleFiles <- function(sampleFiles,
         res <- flowCore::read.flowSet(sampleFiles,
                                       ...)
         
+        # work around to have the full file paths in sampleNames
+        # as apparently this is not done automatically by
+        # flowCore::read.flowSet - only the base filename is stored
+        flowCore::sampleNames(res) <- sampleFiles
+        
         # Add a column with Cell ID
         res <- flowCore::fsApply(
             x = res,
@@ -233,8 +241,12 @@ readSampleFiles <- function(sampleFiles,
                 appendCellID(ff)
             }
         )
+        
+        
     } 
     
+    
+    
     # do we need to do any post processing to the files ?
     # => remove channels or update marker names ? 
     
@@ -513,7 +525,6 @@ compensateFromMatrix <- function(x,
                                  verbose = FALSE,
                                  ...) {
 
-    #browser()
     matrixSource <- match.arg(matrixSource)
     
     if (matrixSource == "import"){
@@ -554,7 +565,6 @@ compensateFromMatrix <- function(x,
                     matrixPath)
         }
         
-        #browser()
         if (matrixSource == "fcs") {
             # obtains compensation matrix
             compensationMatrix <-
